// importing the d3 library's required functions
import { csv, select } from 'd3';
// the scatterPlot function is being imported from a local module
import { scatterPlot } from './scatterPlot';

// Creating the URL from a GitHub Gist to retrieve the Penguins.csv file
const csvUrl = [
  'https://raw.githubusercontent.com/Sruthi1003/Activity-6-Question-3-1-/main/penguins_size.csv', // File name
].join('');

// A function to parse each CSV row and translate specific attributes to numbers
const parseRow = (d) => {
  d.culmen_length_mm = +d.culmen_length_mm;
  d.culmen_depth_mm = +d.culmen_depth_mm;
  d.flipper_length_mm = +d.flipper_length_mm;
  d.body_mass_g = +d.body_mass_g;
  return d;
};

// adjusting the SVG canvas's width and height to fit the dimensions of the window
const width = window.innerWidth;
const height = window.innerHeight - 70;

// Making an SVG element with a defined width and height that is affixed to the page's body
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Main asynchronous function for data loading and plotting creation
const main = async () => {
  // Instantiating a scatter plot with specified settings
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow)) // parsing and loading information from the CSV URL
    .xValue((d) => d.body_mass_g) // Value accessor for X-axis
    .yValue((d) => d.culmen_length_mm) // Value accessor on the Y-axis
    .speciesValue((d) => d.species)
    .margin({
      // Determining the plot's margins
      top: 20,
      right: 20,
      bottom: 40,
      left: 50,
    })
    .radius(5); // The scatter plot points' radius

  // Plot attachment to SVG element
  svg.call(plot);

  // The x-axis value is an array of column names that must be cycled through.
  const columns = [
    'body_mass_g',
    'culmen_depth_mm',
    'flipper_length_mm',
    'culmen_length_mm',
  ];

  // setting up a counter so that it can cycle over the columns
  let i = 0;

  // establishing a time interval to redraw the plot and update the x-axis value every two seconds
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]); // Altering the value accessor for the x-axis
    svg.call(plot); // Plotting again using the updated x-axis values
    i++; // Increasing the counter correspondingly
  }, 2000);
};

// carrying out the main task to develop the plot
main(